/*
 * Purple - Internet Messaging Library
 * Copyright (C) Pidgin Developers <devel@pidgin.im>
 *
 * Purple is the legal property of its developers, whose names are too numerous
 * to list here. Please refer to the COPYRIGHT file distributed with this
 * source distribution.
 *
 * This library is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License as published by the Free
 * Software Foundation; either version 2 of the License, or (at your option)
 * any later version.
 *
 * This library is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for
 * more details.
 *
 * You should have received a copy of the GNU General Public License along with
 * this library; if not, see <https://www.gnu.org/licenses/>.
 */

#if !defined(PURPLE_GLOBAL_HEADER_INSIDE) && !defined(PURPLE_COMPILATION)
# error "only <purple.h> may be included directly"
#endif

#ifndef PURPLE_NOTIFICATION_CONNECTION_ERROR_H
#define PURPLE_NOTIFICATION_CONNECTION_ERROR_H

#include <glib.h>
#include <glib-object.h>

#include "purplenotification.h"
#include "purpleversion.h"

G_BEGIN_DECLS

/**
 * PurpleNotificationConnectionError:
 *
 * A [class@Notification] for connection errors on [class@Account].
 *
 * Since: 3.0
 */

#define PURPLE_TYPE_NOTIFICATION_CONNECTION_ERROR (purple_notification_connection_error_get_type())

PURPLE_AVAILABLE_IN_3_0
G_DECLARE_FINAL_TYPE(PurpleNotificationConnectionError,
                     purple_notification_connection_error, PURPLE,
                     NOTIFICATION_CONNECTION_ERROR, PurpleNotification)

#include "purpleaccount.h"

/**
 * purple_notification_connection_error_new:
 * @id: (nullable): An identifier for this notification.
 * @account: The account.
 *
 * Creates a new [class@Notification] for a connection error on @account.
 *
 * Returns: (nullable): The new notification.
 *
 * Since: 3.0
 */
PURPLE_AVAILABLE_IN_3_0
PurpleNotification *purple_notification_connection_error_new(const char *id, PurpleAccount *account);

G_END_DECLS

#endif /* PURPLE_NOTIFICATION_CONNECTION_ERROR_H */
