/*
 * Purple - Internet Messaging Library
 * Copyright (C) Pidgin Developers <devel@pidgin.im>
 *
 * Purple is the legal property of its developers, whose names are too numerous
 * to list here. Please refer to the COPYRIGHT file distributed with this
 * source distribution.
 *
 * This library is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License as published by the Free
 * Software Foundation; either version 2 of the License, or (at your option)
 * any later version.
 *
 * This library is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for
 * more details.
 *
 * You should have received a copy of the GNU General Public License along with
 * this library; if not, see <https://www.gnu.org/licenses/>.
 */

#ifndef PURPLE_PURPLE_H
#define PURPLE_PURPLE_H

#ifndef __GI_SCANNER__ /* hide this bit from g-ir-scanner */
# ifdef PURPLE_COMPILATION
#  error "libpurple source files should not be including purple.h"
# endif /* PURPLE_COMPILATION */
#endif /* __GI_SCANNER__ */

#include <glib.h>

#ifndef PURPLE_GLOBAL_HEADER_INSIDE
# define PURPLE_GLOBAL_HEADER_INSIDE
#endif /* PURPLE_GLOBAL_HEADER_INSIDE */

#include <libpurple/accounts.h>
#include <libpurple/circularbuffer.h>
#include <libpurple/core.h>
#include <libpurple/debug.h>
#include <libpurple/image.h>
#include <libpurple/network.h>
#include <libpurple/plugins.h>
#include <libpurple/prefs.h>
#include <libpurple/proxy.h>
#include <libpurple/purpleaccount.h>
#include <libpurple/purpleaccountmanager.h>
#include <libpurple/purpleaccountoption.h>
#include <libpurple/purpleaccountusersplit.h>
#include <libpurple/purpleaddcontactrequest.h>
#include <libpurple/purpleauthorizationrequest.h>
#include <libpurple/purpleavatar.h>
#include <libpurple/purplebadge.h>
#include <libpurple/purplebadgemanager.h>
#include <libpurple/purplebadges.h>
#include <libpurple/purplechanneljoindetails.h>
#include <libpurple/purplecommand.h>
#include <libpurple/purplecommands.h>
#include <libpurple/purplecommandmanager.h>
#include <libpurple/purpleconnection.h>
#include <libpurple/purplecontact.h>
#include <libpurple/purplecontactinfo.h>
#include <libpurple/purplecontactmanager.h>
#include <libpurple/purpleconversation.h>
#include <libpurple/purpleconversationmanager.h>
#include <libpurple/purpleconversationmember.h>
#include <libpurple/purpleconversationmembers.h>
#include <libpurple/purplecreateconversationdetails.h>
#include <libpurple/purplecredentialmanager.h>
#include <libpurple/purplecredentialprovider.h>
#include <libpurple/purpledebugui.h>
#include <libpurple/purplefiletransfer.h>
#include <libpurple/purplefiletransfermanager.h>
#include <libpurple/purplegdkpixbuf.h>
#include <libpurple/purplegio.h>
#include <libpurple/purplehistoryadapter.h>
#include <libpurple/purplehistorymanager.h>
#include <libpurple/purpleidlemanager.h>
#include <libpurple/purpleattachment.h>
#include <libpurple/purplekeyvaluepair.h>
#include <libpurple/purplemarkup.h>
#include <libpurple/purplemenu.h>
#include <libpurple/purplemessage.h>
#include <libpurple/purplemessages.h>
#include <libpurple/purplenoopcredentialprovider.h>
#include <libpurple/purplenotification.h>
#include <libpurple/purplenotificationaddcontact.h>
#include <libpurple/purplenotificationauthorizationrequest.h>
#include <libpurple/purplenotificationconnectionerror.h>
#include <libpurple/purplenotificationlink.h>
#include <libpurple/purplenotificationmanager.h>
#include <libpurple/purpleoptions.h>
#include <libpurple/purplepath.h>
#include <libpurple/purpleperson.h>
#include <libpurple/purpleplugininfo.h>
#include <libpurple/purplepresence.h>
#include <libpurple/purplepresencemanager.h>
#include <libpurple/purpleprotocol.h>
#include <libpurple/purpleprotocolcontacts.h>
#include <libpurple/purpleprotocolconversation.h>
#include <libpurple/purpleprotocolfiletransfer.h>
#include <libpurple/purpleprotocolmanager.h>
#include <libpurple/purpleprotocolroster.h>
#include <libpurple/purpleprotocolwhiteboard.h>
#include <libpurple/purpleproxyinfo.h>
#include <libpurple/purplesavedpresence.h>
#include <libpurple/purplesqlite3.h>
#include <libpurple/purplesqlitehistoryadapter.h>
#include <libpurple/purpletags.h>
#include <libpurple/purpletyping.h>
#include <libpurple/purpleui.h>
#include <libpurple/purpleversion.h>
#include <libpurple/purplewhiteboard.h>
#include <libpurple/purplewhiteboardmanager.h>
#include <libpurple/purplewhiteboardops.h>
#include <libpurple/purplewhiteboarduiops.h>
#include <libpurple/request.h>
#include <libpurple/util.h>
#include <libpurple/xmlnode.h>
#include <libpurple/request/purplerequestfield.h>
#include <libpurple/request/purplerequestfieldaccount.h>
#include <libpurple/request/purplerequestfieldbool.h>
#include <libpurple/request/purplerequestfieldchoice.h>
#include <libpurple/request/purplerequestfieldimage.h>
#include <libpurple/request/purplerequestfieldint.h>
#include <libpurple/request/purplerequestfieldlabel.h>
#include <libpurple/request/purplerequestfieldlist.h>
#include <libpurple/request/purplerequestfieldstring.h>
#include <libpurple/request/purplerequestgroup.h>
#include <libpurple/request/purplerequestpage.h>
#include <libpurple/purpleversionconsts.h>
#include <libpurple/purpleenums.h>

#undef PURPLE_GLOBAL_HEADER_INSIDE

#endif /* PURPLE_PURPLE_H */
